caellion-python-commons: caellion/pycommons/hashing/file_hashing.py File Reference

caellion-python-commons

Classes | Namespaces
file_hashing.py File Reference

Go to the source code of this file.

## Classes
class | caellion.pycommons.hashing.file_hashing.UnsupportedAlgorithmException
| This exception is raised whenever provided algorithm is not one of allowed algorithms. More...
class | caellion.pycommons.hashing.file_hashing.AlreadyDoneException
| This exception is raised when hashing was requested on a FileHasher that has already finished hashing. More...
class | caellion.pycommons.hashing.file_hashing.NotDoneYetException
| This exception is raised when a hash was requested from a FileHasher that has not hashed any file yet. More...
class | caellion.pycommons.hashing.file_hashing.FileHasher
| This class provides hashlib-based file hasher. More...

## Namespaces
| caellion.pycommons.hashing.file_hashing
| This module provides utilities related to hashing files.